@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2016 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -27,13 +27,10 @@ class ImportExportVCardTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ImportExportVCardTest(QObject *parent = nullptr);
+    explicit ImportExportVCardTest(QObject *parent = Q_NULLPTR);
     ~ImportExportVCardTest();
 private Q_SLOTS:
     void shouldExportFullTestVcard4();
-    void shouldExportMiscElementVcard4();
-    void shouldExportMemberElementVcard4();
-    void shouldExportMissingNewlineVcard4();
 };
 
 #endif // IMPORTEXPORTVCARDTEST_H
