@@ -1,6 +1,6 @@
 /*
     This file is part of libkabc.
-    Copyright (c) 2015 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -31,6 +31,7 @@ public:
     ~ImppTest();
 
 private Q_SLOTS:
+    void shouldParseImppVcard4();
     void shouldHaveDefaultValue();
     void shouldAssignValue();
     void shouldSerialized();
@@ -45,7 +46,7 @@ private Q_SLOTS:
     void shouldExportType();
 
     void shouldExportWithParameters();
-    void shouldShouldNoyExportTwiceServiceType();
+    void shouldShouldNotExportTwiceServiceType();
 };
 
 #endif // IMPPTEST_H
