@@ -64,7 +64,6 @@ public:
         mAdditionalName = other.mAdditionalName;
         mPrefix = other.mPrefix;
         mSuffix = other.mSuffix;
-        mNickName = other.mNickName;
         mBirthday = other.mBirthday;
         mMailer = other.mMailer;
         mTimeZone = other.mTimeZone;
@@ -115,7 +114,6 @@ public:
     QString mAdditionalName;
     QString mPrefix;
     QString mSuffix;
-    QString mNickName;
     QDateTime mBirthday;
     QString mMailer;
     TimeZone mTimeZone;
@@ -152,6 +150,7 @@ public:
     Title::List mTitleExtraList;
     Role::List mRoleExtraList;
     Org::List mOrgExtraList;
+    NickName::List mNickNameExtraList;
     bool mEmpty    : 1;
     bool mChanged  : 1;
 
@@ -232,12 +231,6 @@ bool Addressee::operator==(const Addressee &addressee) const
         return false;
     }
 
-    if (d->mNickName != addressee.d->mNickName &&
-            !(d->mNickName.isEmpty() && addressee.d->mNickName.isEmpty())) {
-        qCDebug(KCONTACTS_LOG) << "nickName differs";
-        return false;
-    }
-
     if (d->mBirthday != addressee.d->mBirthday) {
         qCDebug(KCONTACTS_LOG) << "birthday differs";
         return false;
@@ -399,6 +392,11 @@ bool Addressee::operator==(const Addressee &addressee) const
         qCDebug(KCONTACTS_LOG) << "Extra Organization List differs";
         return false;
     }
+
+    if (!listEquals(d->mNickNameExtraList, addressee.d->mNickNameExtraList)) {
+        qCDebug(KCONTACTS_LOG) << "Extra NickName List differs";
+        return false;
+    }
     return true;
 }
 
@@ -730,17 +728,48 @@ QString Addressee::suffixLabel()
 
 void Addressee::setNickName(const QString &nickName)
 {
-    if (nickName == d->mNickName) {
-        return;
+    NickName t(nickName);
+    if (!d->mNickNameExtraList.isEmpty()) {
+        t = d->mNickNameExtraList.takeFirst();
+        t.setNickName(nickName);
+        d->mNickNameExtraList.prepend(t);
+        d->mEmpty = false;
+    } else {
+        insertExtraNickName(t);
     }
+}
 
+void Addressee::setNickName(const NickName &nickName)
+{
+    insertExtraNickName(nickName);
+}
+
+void Addressee::insertExtraNickName(const NickName &nickName)
+{
+    if (nickName.isValid()) {
+        d->mEmpty = false;
+        d->mNickNameExtraList.append(nickName);
+    }
+}
+
+void Addressee::setExtraNickNameList(const NickName::List &nickNameList)
+{
     d->mEmpty = false;
-    d->mNickName = nickName;
+    d->mNickNameExtraList = nickNameList;
+}
+
+NickName::List Addressee::extraNickNameList() const
+{
+    return d->mNickNameExtraList;
 }
 
 QString Addressee::nickName() const
 {
-    return d->mNickName;
+    if (d->mNickNameExtraList.isEmpty()) {
+        return {};
+    } else {
+        return d->mNickNameExtraList.at(0).nickname();
+    }
 }
 
 QString Addressee::nickNameLabel()
@@ -1003,7 +1032,7 @@ void Addressee::setRole(const QString &role)
         d->mRoleExtraList.prepend(t);
         d->mEmpty = false;
     } else {
-        insertExtraRole(role);
+        insertExtraRole(t);
     }
 }
 
@@ -1055,7 +1084,7 @@ void Addressee::setOrganization(const QString &organization)
         d->mOrgExtraList.prepend(t);
         d->mEmpty = false;
     } else {
-        insertExtraOrganization(organization);
+        insertExtraOrganization(t);
     }
 }
 
@@ -2359,7 +2388,6 @@ QDataStream &KContacts::operator<<(QDataStream &s, const Addressee &a)
     s << a.d->mAdditionalName;
     s << a.d->mPrefix;
     s << a.d->mSuffix;
-    s << a.d->mNickName;
     s << a.d->mBirthday;
     s << a.d->mMailer;
     s << a.d->mTimeZone;
@@ -2395,6 +2423,7 @@ QDataStream &KContacts::operator<<(QDataStream &s, const Addressee &a)
     s << a.d->mTitleExtraList;
     s << a.d->mRoleExtraList;
     s << a.d->mOrgExtraList;
+    s << a.d->mNickNameExtraList;
 
     return s;
 }
@@ -2410,7 +2439,6 @@ QDataStream &KContacts::operator>>(QDataStream &s, Addressee &a)
     s >> a.d->mAdditionalName;
     s >> a.d->mPrefix;
     s >> a.d->mSuffix;
-    s >> a.d->mNickName;
     s >> a.d->mBirthday;
     s >> a.d->mMailer;
     s >> a.d->mTimeZone;
@@ -2448,6 +2476,7 @@ QDataStream &KContacts::operator>>(QDataStream &s, Addressee &a)
     s >> a.d->mTitleExtraList;
     s >> a.d->mRoleExtraList;
     s >> a.d->mOrgExtraList;
+    s >> a.d->mNickNameExtraList;
     a.d->mEmpty = false;
 
     return s;
